
#' Make full dataset
#'
#' Assemble complete dataset for analysis combining climatic and fitness/performance data (as provided by Bastien).
#'
#' @return File "fulldata.csv" written to disk (\code{data} folder).
#' @export
#' @import readr
#' @import dplyr
#'

make_full_dataset <- function(performance.data = "data-raw/Pulido et al_SM1_Data_2017-06-13.csv") {

  clidata <- read_csv("data/clidata.csv")
  fitness <- read_csv(performance.data)

  names(fitness) <- tolower(names(fitness))

  # Merge climate and fitness data
  fulldata <- merge(dplyr::select(fitness, -fitness.2),
                    dplyr::select(clidata, -ref, -kingdom, -habitat, -fitness),
                    by.x = c("study.id", "species", "variable", "margin"),
                    by.y = c("study.id", "species", "variable", "region"), all = TRUE) %>%
    # filter(!is.na(yi)) %>%
    dplyr::select(study.id, study.sp.id, study.sp.vble.id, study.sp.vble.reg.id, case.id, year, ref,
                  review, journal, citation, kingdom, habitat, species, variable, fitness, everything())

  if (nrow(fulldata) != nrow(clidata))
    stop("\nThere are mismatches between climate and fitness datasets (e.g. species, variable names...).\n")

  ## checks
  all.equal(fulldata$npop.margin, fulldata$n.margin)
  which(fulldata$npop.margin != fulldata$n_margin)

  all.equal(fulldata$npop.centre, fulldata$n.center)
  which(fulldata$npop.centre != fulldata$n_center)


  write_csv(fulldata, "data/fulldata.csv")


}

