
library(MarginalPerformance)



#### RECREATE PACKAGE ENVIRONMENT ######################

## Uncomment line below to recreate package environment for that date ##
# recreate_packages(date = "2017-07-06")

# R version used: 3.4.1
# Restart R session to come back to normal user library afterwards

# Use delete_packages to delete the folder containing packages afterwards
# delete_packages()


#######################################################

library(rmarkdown)

render("README.Rmd")



####### DATA PREPARATION #################################

### Prepare coordinates data ###
render(input = "data-raw/coords_dataprep.Rmd")


### Extract climate data ###
render(input = "data-raw/climate_data_extraction.Rmd")


### Prepare climate data for analysis ###

# Temperature (climvar = tmp)
render(input = "data-raw/climate_data_preparation.Rmd", params = list(climvar = "tmp"),
       output_file = "climate_data_preparation_tmp.pdf")


# Precipitation (climvar = pre)
render(input = "data-raw/climate_data_preparation.Rmd", params = list(climvar = "pre"),
       output_file = "climate_data_preparation_pre.pdf")


# Sea surface temperatures (climvar = sst)
render(input = "data-raw/climate_data_preparation.Rmd", params = list(climvar = "sst"),
       output_file = "climate_data_preparation_sst.pdf")



### Combine and assemble climatic dataset ###
make_clim_dataset()


### Create full dataset ###
make_full_dataset()



####### ANALYSES ###########################################################

### Is performance in the margin related to geographic distance to central populations? ###
render("analyses/Performance_vs_distance_centroids.Rmd",
       output_dir = "analyses/output")

### Is marginal performance related to climatic difference with central populations? ###
render("analyses/Performance_vs_climate.Rmd",
       output_dir = "analyses/output")





######### FIGURES ###########################################################

render("manuscript/figures/Fig_occmap.Rmd")

render("manuscript/figures/Figure_Core-Periphery-Theory.Rmd")

render("manuscript/figures/Figures_Fitness.Rmd")


